@@ -1,7 +1,7 @@
 package Data::Unixish::ANSI::color;
 
-our $DATE = '2015-08-17'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2015-09-03'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 use 5.010;
 use strict;
@@ -84,7 +84,7 @@ Data::Unixish::ANSI::color - Colorize text with ANSI color codes
 
 =head1 VERSION
 
-This document describes version 0.06 of Data::Unixish::ANSI::color (from Perl distribution Data-Unixish-ANSI), released on 2015-08-17.
+This document describes version 0.07 of Data::Unixish::ANSI::color (from Perl distribution Data-Unixish-ANSI), released on 2015-09-03.
 
 =head1 SYNOPSIS
 
@@ -103,7 +103,7 @@ In command line:
 
 =head2 color(%args) -> [status, msg, result, meta]
 
-{en_US Colorize text with ANSI color codes}.
+Colorize text with ANSI color codes.
 
 Arguments ('*' denotes required arguments):
 
@@ -111,22 +111,20 @@ Arguments ('*' denotes required arguments):
 
 =item * B<color>* => I<str>
 
-{en_US The color to use for each item}.
+The color to use for each item.
 
-{en_US 
 Example: C<red>, C<bold blue>, C<yellow on_magenta>, C<black on_bright_yellow>. See
 Perl module Term::ANSIColor for more details.
 
 You can also supply raw ANSI code.
-}
 
 =item * B<in> => I<array>
 
-{en_US Input stream (e.g. array or filehandle)}.
+Input stream (e.g. array or filehandle).
 
 =item * B<out> => I<any>
 
-{en_US Output stream (e.g. array or filehandle)}.
+Output stream (e.g. array or filehandle).
 
 =back
 
@@ -147,7 +145,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Data-Unixi
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Data-Unixish-ansi>.
+Source repository is at L<https://github.com/perlancar/perl-Data-Unixish-ansi>.
 
 =head1 BUGS
 
