@@ -1,7 +1,7 @@
 package Data::Unixish::ANSI::highlight;
 
-our $DATE = '2015-08-17'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2015-09-03'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 use 5.010;
 use strict;
@@ -123,7 +123,7 @@ Data::Unixish::ANSI::highlight - Highlight string/pattern with color
 
 =head1 VERSION
 
-This document describes version 0.06 of Data::Unixish::ANSI::highlight (from Perl distribution Data-Unixish-ANSI), released on 2015-08-17.
+This document describes version 0.07 of Data::Unixish::ANSI::highlight (from Perl distribution Data-Unixish-ANSI), released on 2015-09-03.
 
 =head1 SYNOPSIS
 
@@ -142,7 +142,7 @@ In command line:
 
 =head2 highlight(%args) -> [status, msg, result, meta]
 
-{en_US Highlight string/pattern with color}.
+Highlight string/pattern with color.
 
 Arguments ('*' denotes required arguments):
 
@@ -150,42 +150,36 @@ Arguments ('*' denotes required arguments):
 
 =item * B<ci> => I<bool> (default: 0)
 
-{en_US Whether to search case-insensitively}.
+Whether to search case-insensitively.
 
 =item * B<color> => I<str> (default: "bold red")
 
-{en_US The color to use for each item}.
+The color to use for each item.
 
-{en_US 
 Example: C<red>, C<bold blue>, C<yellow on_magenta>, C<black on_bright_yellow>. See
 Perl module Term::ANSIColor for more details.
 
 You can also supply raw ANSI code.
-}
 
 =item * B<in> => I<array>
 
-{en_US Input stream (e.g. array or filehandle)}.
+Input stream (e.g. array or filehandle).
 
 =item * B<out> => I<any>
 
-{en_US Output stream (e.g. array or filehandle)}.
+Output stream (e.g. array or filehandle).
 
 =item * B<pattern> => I<str>
 
-{en_US Regex pattern to search}.
+Regex pattern to search.
 
-{en_US 
 Either this or C<string> is required.
-}
 
 =item * B<string> => I<str>
 
-{en_US String to search}.
+String to search.
 
-{en_US 
 Either this or C<pattern> is required.
-}
 
 =back
 
@@ -206,7 +200,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Data-Unixi
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Data-Unixish-ansi>.
+Source repository is at L<https://github.com/perlancar/perl-Data-Unixish-ansi>.
 
 =head1 BUGS
 
