@@ -1,7 +1,7 @@
 package Data::Unixish::ANSI::strip;
 
-our $DATE = '2015-08-17'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2015-09-03'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 use 5.010;
 use strict;
@@ -57,7 +57,7 @@ Data::Unixish::ANSI::strip - Strip ANSI codes (colors, etc) from text
 
 =head1 VERSION
 
-This document describes version 0.06 of Data::Unixish::ANSI::strip (from Perl distribution Data-Unixish-ANSI), released on 2015-08-17.
+This document describes version 0.07 of Data::Unixish::ANSI::strip (from Perl distribution Data-Unixish-ANSI), released on 2015-09-03.
 
 =head1 SYNOPSIS
 
@@ -77,7 +77,7 @@ In command line:
 
 =head2 strip(%args) -> [status, msg, result, meta]
 
-{en_US Strip ANSI codes (colors, etc) from text}.
+Strip ANSI codes (colors, etc) from text.
 
 Arguments ('*' denotes required arguments):
 
@@ -85,11 +85,11 @@ Arguments ('*' denotes required arguments):
 
 =item * B<in> => I<array>
 
-{en_US Input stream (e.g. array or filehandle)}.
+Input stream (e.g. array or filehandle).
 
 =item * B<out> => I<any>
 
-{en_US Output stream (e.g. array or filehandle)}.
+Output stream (e.g. array or filehandle).
 
 =back
 
@@ -110,7 +110,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Data-Unixi
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Data-Unixish-ansi>.
+Source repository is at L<https://github.com/perlancar/perl-Data-Unixish-ansi>.
 
 =head1 BUGS
 
